@@ -1087,9 +1087,11 @@ gncInvoiceDetachFromLot (GNCLot *lot)
     KvpFrame *kvp;
 
     if (!lot) return;
-
+    gnc_lot_begin_edit (lot);
     kvp = gnc_lot_get_slots (lot);
     kvp_frame_set_slot_path (kvp, NULL, GNC_INVOICE_ID, GNC_INVOICE_GUID, NULL);
+    qof_instance_set_dirty (QOF_INSTANCE (lot));
+    gnc_lot_commit_edit (lot);
 }
 
 static void
@@ -1103,9 +1105,12 @@ gncInvoiceAttachToLot (GncInvoice *invoice, GNCLot *lot)
 
     if (invoice->posted_lot) return;	/* Cannot reset invoice's lot */
 
+    gnc_lot_begin_edit (lot);
     kvp = gnc_lot_get_slots (lot);
     value = kvp_value_new_guid (qof_instance_get_guid (QOF_INSTANCE(invoice)));
     kvp_frame_set_slot_path (kvp, value, GNC_INVOICE_ID, GNC_INVOICE_GUID, NULL);
+    qof_instance_set_dirty (QOF_INSTANCE (lot));
+    gnc_lot_commit_edit (lot);
     kvp_value_delete (value);
     gncInvoiceSetPostedLot (invoice, lot);
 }
@@ -1366,7 +1371,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
                             gnc_numeric converted_amount;
                             xaccSplitSetValue(split, (reverse ? gnc_numeric_neg(value) : value));
                             converted_amount = gnc_numeric_div(value, gnc_price_get_value(price), GNC_DENOM_AUTO, GNC_HOW_RND_ROUND_HALF_UP);
-                            printf("converting from %f to %f\n", gnc_numeric_to_double(value), gnc_numeric_to_double(converted_amount));
+                            DEBUG("converting from %f to %f\n", gnc_numeric_to_double(value), gnc_numeric_to_double(converted_amount));
                             xaccSplitSetAmount(split, reverse ? gnc_numeric_neg(converted_amount) : converted_amount);
                         }
                     }
@@ -1457,7 +1462,7 @@ Transaction * gncInvoicePostToAccount (GncInvoice *invoice, Account *acc,
                 gnc_numeric converted_amount;
                 xaccSplitSetValue(split, (reverse ? gnc_numeric_neg(acc_val->value) : acc_val->value));
                 converted_amount = gnc_numeric_div(acc_val->value, gnc_price_get_value(price), GNC_DENOM_AUTO, GNC_HOW_RND_ROUND_HALF_UP);
-                printf("converting from %f to %f\n", gnc_numeric_to_double(acc_val->value), gnc_numeric_to_double(converted_amount));
+                DEBUG("converting from %f to %f\n", gnc_numeric_to_double(acc_val->value), gnc_numeric_to_double(converted_amount));
 
                 xaccSplitSetAmount(split, reverse ? gnc_numeric_neg(converted_amount) : converted_amount);
             }
